"""
*****************************************************************
Licensed Materials - Property of IBM
(C) Copyright IBM Corp. 2019. All Rights Reserved.
US Government Users Restricted Rights - Use, duplication or
disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*****************************************************************
"""

import tensorflow as tf
import ddl
import sys
import numpy as np
from sklearn.model_selection import train_test_split

def main ():
    #Create dataset
    x_data = np.random.uniform(low=0, high=10, size=(10000, 1))
    noise = np.random.randn(x_data.shape[0], x_data.shape[1])
    y_data = (0.5 * x_data) + 5 + noise

    #Split train and test data
    x_train, x_test, y_train, y_test = train_test_split(x_data, y_data, test_size=0.3)

    #Define feature column
    feature_col = [tf.feature_column.numeric_column('x', shape=x_data.shape[1])]

    #Instantiate an estimator with feature column
    estimator = tf.estimator.LinearRegressor(feature_columns=feature_col)

    #Define train and test functions
    train_input_fn = tf.estimator.inputs.numpy_input_fn(x={'x': x_train},
                     y=y_train, batch_size=8, num_epochs=None, shuffle=False)

    test_input_fn  = tf.estimator.inputs.numpy_input_fn(x={'x': x_test},
                     y=y_test, batch_size=8, num_epochs=100, shuffle=False)

    #Call train and evaluate in a loop
    for i in range(0, 10):
        estimator.train(input_fn=train_input_fn, steps=100)
        train_metrics = estimator.evaluate(input_fn=train_input_fn, steps=100)
        test_metrics = estimator.evaluate(input_fn=test_input_fn, steps=100)

        print ("TRAIN METRICS" + str(train_metrics))
        print ("TEST METRICS" + str(test_metrics))

if __name__ == '__main__':
    main()
